@@ -1,4 +1,4 @@
-#%% begin initialize drupal-6.4-noname-P1
+#%% begin initialize drupal-6.8-noname-P1
 ###################################################################
 export LANG=C
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
@@ -14,7 +14,7 @@ WWW=$ROOT/home/www
 if [ -f $ROOT/opt/htdocs/drupal6 ]; then
   mv $ROOT/opt/htdocs/drupal6 $ROOT/opt/htdocs/drupal6.bak
 fi
-(cd $ROOT/opt/htdocs; ln -sf drupal-6.4 drupal6 )
+(cd $ROOT/opt/htdocs; rm -f drupal6; ln -sf drupal-6.8 drupal6 )
 
 FQDN=`hostname -f`
 if [ ".$FQDN" = "." ]; then
